<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2012 David Frerich (dfrerich@cdfre.de)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

namespace IMIA\Base\Hook;

/**
 * @package     imia_base
 * @subpackage  Hook
 * @author      David Frerich <d.frerich@imia.de>
 */
class PageRepositoryGetRecordOverlayHook implements \TYPO3\CMS\Frontend\Page\PageRepositoryGetRecordOverlayHookInterface
{
    /**
     * @var array
     */
    protected $l10nExcludeFields = array(
        'field_container_smallcontent',
        'field_container_content',
        'field_col1_inner',
        'field_col2_inner',
        'field_col3_inner',
        'field_col1',
        'field_col2',
        'field_col3',
    );

    /**
     * Enables to preprocess a record overlay
     *
     * @param string $table
     * @param array $row
     * @param integer $sys_language_content
     * @param string $OLmode
     * @param \TYPO3\CMS\Frontend\Page\PageRepository $parent
     */
    public function getRecordOverlay_preProcess($table, &$row, &$sys_language_content, $OLmode, \TYPO3\CMS\Frontend\Page\PageRepository $parent)
    {
        if ($sys_language_content > 0) {
            if ($row['CType'] == 'templavoila_pi1') {
                if ($row['tx_templavoila_flex']) {
                    $fceDS =  \TYPO3\CMS\Core\Utility\GeneralUtility::xml2array($row['tx_templavoila_flex']);
                    foreach ($fceDS['data']['sDEF']['lDEF'] AS $fieldName => $fieldData) {
                        if (in_array($fieldName, $this->getL10nExcludeFields($table, $row))) {
                            $row['_tmpORGFCEData'][$row['uid']][$fieldName] = $fieldData['vDEF'];
                        }
                    }
                }
            }
        }
    }

    /**
     * Enables to postprocess a record overlay
     *
     * @param string $table
     * @param array $row
     * @param integer $sys_language_content
     * @param string $OLmode
     * @param \TYPO3\CMS\Frontend\Page\PageRepository $parent
     */
    public function getRecordOverlay_postProcess($table, &$row, &$sys_language_content, $OLmode, \TYPO3\CMS\Frontend\Page\PageRepository $parent)
    {
        if ($sys_language_content > 0) {
            if ($row['CType'] == 'templavoila_pi1') {
                if ($row['tx_templavoila_flex']) {
                    $fceDS =  \TYPO3\CMS\Core\Utility\GeneralUtility::xml2array($row['tx_templavoila_flex']);
                    foreach ($fceDS['data']['sDEF']['lDEF'] AS $fieldName => $fieldData) {
                        if (in_array($fieldName, $this->getL10nExcludeFields($table, $row))) {
                            $fceDS['data']['sDEF']['lDEF'][$fieldName]['vDEF'] = $row['_tmpORGFCEData'][$row['uid']][$fieldName];
                        }
                    }
                    unset($row['_tmpORGFCEData']);
                    $row['tx_templavoila_flex'] =  \TYPO3\CMS\Core\Utility\GeneralUtility::array2xml($fceDS);
                }
            }
        }
    }

    /**
     * @todo dynamicaly read l10n_mode from ds
     *
     * @param string $table
     * @param array $row
     * @return array
     */
    protected function getL10nExcludeFields($table, $row)
    {
        return $this->l10nExcludeFields;
    }
}
