<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2013 IMIA net based solutions (d.frerich@imia.de)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

namespace IMIA\Base\Utility;

/**
 * @package     imia_base
 * @subpackage  Utility
 * @author      David Frerich <d.frerich@imia.de>
 */
class Helper
{
    /**
     * @param boolean $includeOnly
     * @param array $defaultLanguage
     */
    static public function addDynamicConfiguration($includeOnly = false, $defaultLanguage = array('de', 'de_DE', 'bypass'))
    {
        self::addDomainTypoScriptConstants($includeOnly);
        self::addDynamicLanguageTypoScript($includeOnly, $defaultLanguage);
        self::updateRealUrlConfiguration($includeOnly, $defaultLanguage);
    }

    /**
     * @param boolean $includeOnly
     */
    static public function addDomainTypoScriptConstants($includeOnly = false)
    {
        $cache = new Cache('imia_domainconstants');

        if ($cache->exists()) {
            $domainTsConsts = $cache->load();
        } elseif (!$includeOnly && $GLOBALS['TYPO3_DB']) {
            $domainTsConsts = '';
            $domains = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('pid, domainName', 'sys_domain',
                '1=1' . \TYPO3\CMS\Backend\Utility\BackendUtility::BEenableFields('sys_domain'), '', 'sorting asc');

            if (array_key_exists(0, $domains)) {
                $domainTsConsts .= 'config.baseUrl = ' . $domains[0]['domainName'] . "\n\n";
            }
            foreach ($domains as $domain) {
                $domainTsConsts .= '[globalString = IENV:HTTP_HOST = ' . $domain['domainName'] . ']' . "\n" .
                    '    config.baseUrl = ' . $domain['domainName'] . "\n";
            }

            if ($domainTsConsts) {
                $domainTsConsts .= '[end]';
            }

            $cache->write($domainTsConsts);
        }

        \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::addTypoScript('imia_base', 'constants', $domainTsConsts, true);
    }

    /**
     * @param boolean $includeOnly
     * @param array $defaultLanguage
     */
    public static function addDynamicLanguageTypoScript($includeOnly = false, $defaultLanguage = array('de', 'de_DE', 'bypass'))
    {
        $cache = new Cache('imia_tslanguage');

        if ($cache->exists()) {
            $typoscript = $cache->load();
        } elseif (!$includeOnly && $GLOBALS['TYPO3_DB']) {
            $typoscript = 'config {
    linkVars = L
    sys_language_uid = 0
    language = ' . $defaultLanguage[0] . '
    locale_all = ' . $defaultLanguage[1] . '.UTF-8
    htmlTag_langKey = ' . $defaultLanguage[0] . '
}' . "\n\n";

            $languages = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('sys_language.uid, static_languages.lg_iso_2, static_languages.lg_collate_locale',
                'sys_language, static_languages ', 'sys_language.static_lang_isocode = static_languages.uid' .
                \TYPO3\CMS\Backend\Utility\BackendUtility::BEenableFields('sys_language'));

            foreach ($languages as $language) {
                $typoscript .= '[globalVar = GP:L = ' . $language['uid'] . ']
    config {
        sys_language_uid = ' . $language['uid'] . '
        language = ' . strtolower($language['lg_iso_2']) . '
        locale_all = ' . ($language['lg_collate_locale'] ?: strtolower($language['lg_iso_2'])) . '.UTF-8
        htmlTag_langKey = ' . strtolower($language['lg_iso_2']) . '
    }' . "\n";
            }

            $typoscript .= '[end]';

            $cache->write($typoscript);
        }

        if ($typoscript) {
            \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::addTypoScript('imia_base', 'setup', $typoscript, true);
        }
    }

    /**
     * @param boolean $includeOnly
     * @param array $defaultLanguage
     */
    static public function updateRealUrlConfiguration($includeOnly = false, $defaultLanguage = array('de', 'de_DE', 'bypass'))
    {
        $cache = new Cache('imia_realurl');

        if ($cache->exists()) {
            $realUrlConfig = $cache->load();
        } elseif (!$includeOnly && $GLOBALS['TYPO3_DB']) {
            $realUrlConfig = $GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['realurl'];

            $realUrlLanguagePreVar = array(
                'GETvar'    => 'L',
                'valueMap'  => array(),
                'noMatch'   => 'bypass',
            );

            if ($defaultLanguage && $defaultLanguage[2] != 'bypass') {
                $realUrlLanguagePreVar['valueMap'][strtolower($defaultLanguage[0])] = 0;
                 $realUrlLanguagePreVar['valueDefault'] = strtolower($defaultLanguage[0]);
                unset($realUrlLanguagePreVar['noMatch']);
            }

            $languages = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('sys_language.uid, static_languages.lg_iso_2',
                'sys_language, static_languages ', 'sys_language.static_lang_isocode = static_languages.uid' .
                \TYPO3\CMS\Backend\Utility\BackendUtility::BEenableFields('sys_language'));

            foreach ($languages as $language) {
                $realUrlLanguagePreVar['valueMap'][strtolower($language['lg_iso_2'])] = (int)$language['uid'];
            }
            array_unshift($realUrlConfig['_DEFAULT']['preVars'], $realUrlLanguagePreVar);

            $domains = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('pid, domainName', 'sys_domain',
                '1=1' . \TYPO3\CMS\Backend\Utility\BackendUtility::BEenableFields('sys_domain'));

            foreach ($domains as $domain) {
                $realUrlConfig[$domain['domainName']] = $realUrlConfig['_DEFAULT'];
                $realUrlConfig[$domain['domainName']]['pagePath']['rootpage_id'] = (int)$domain['pid'];
            }

            $cache->write($realUrlConfig);
        }

        if ($realUrlConfig) {
            $GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['realurl'] = $realUrlConfig;
        }
    }

    /**
     * @param string $color
     * @return array
     */
    static public function convertHex2RGB($color)
    {
        $color = str_replace('#', '', $color);

        if (strlen($color) != 6) {
            return array(0, 0, 0);
        } else {
            $rgb = array();
            for ($x = 0; $x < 3; $x++){
                $rgb[$x] = hexdec(substr($color,(2 * $x), 2));
            }

            return $rgb;
        }
    }

    /**
     * @param string $content
     * @param array $conf
     * @return string
     */
    public function templavoilaContentMenu($content = '', $conf = array())
    {
        $cObj = $GLOBALS['TSFE']->cObj;
        $page = $GLOBALS['TSFE']->page;
        $conf = $conf['userFunc.'];

        $dataStructure = \TYPO3\CMS\Core\Utility\GeneralUtility::xml2array($page['tx_templavoila_flex']);
        $contentElementUids = array_map('intval', explode(',', $dataStructure['data']['sDEF']['lDEF'][$conf['field']]['vDEF']));

        $contentUid = $cObj->cObjGetSingle($conf['contentUid'], $conf['contentUid.']);
        if ($contentUid && !$conf['displayCurrent']) {
            $contentElementUids = array_diff($contentElementUids, array((int)$contentUid));
        }

        $displayField = 'header';
        if (array_key_exists('displayField', $conf)) {
            $displayField = $conf['displayField'];
        }

        $contentElements = array();
        $res = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
            '*',
            'tt_content',
            'tt_content.uid IN(' . implode(',', $contentElementUids) . ')' .
                $GLOBALS['TSFE']->sys_page->enableFields('tt_content')
        );

        if($res) {
            while ($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res)) {
                if (is_array($row) && $row['sys_language_uid'] != $GLOBALS['TSFE']->sys_language_content
                  && $GLOBALS['TSFE']->sys_language_contentOL) {
                    $row = $GLOBALS['TSFE']->sys_page->getRecordOverlay('tt_content', $row,
                        $GLOBALS['TSFE']->sys_language_content, $GLOBALS['TSFE']->sys_language_contentOL);
                }
                $contentElements[$row['uid']] = $row;
            }
        }

        if (array_key_exists('CUR.', $conf['menuItem.'])) {
            $menuItemCURConf = $conf['menuItem.']['CUR.'];
        } elseif (array_key_exists('ACT.', $conf['menuItem.'])) {
            $menuItemCURConf = $conf['menuItem.']['ACT.'];
        }
        if (array_key_exists('NO.', $conf['menuItem.'])) {
            $menuItemNOConf = $conf['menuItem.']['NO.'];
        } else {
            $menuItemNOConf = $conf['menuItem.'];
        }

        foreach ($contentElementUids AS $contentElementUid) {
            if (array_key_exists($contentElementUid, $contentElements)) {
                $linkConf = array(
                    'parameter' => $page['uid'],
                    'section'   => $contentElementUid,
                );

                if ($contentUid == $contentElementUid) {
                    $menuItemConf = $menuItemCURConf;
                } else {
                    $menuItemConf = $menuItemNOConf;
                }

                if (array_key_exists($displayField, $contentElements[$contentElementUid])) {
                    $title = $contentElements[$contentElementUid][$displayField];
                }

                if (!$title) {
                    $title = $contentElements[$contentElementUid]['header'];
                }

                $menuItemConf['value'] = $cObj->typoLink($title, $linkConf);
                $elements[] = $cObj->cObjGetSingle('TEXT', $menuItemConf);
            }
        }

        return implode("\n", $elements);
    }

    /**
     * @param array $content
     * @param array $conf
     * @return array
     */
    public function arrayReverse(array $content, $conf)
    {
        return array_reverse($content);
    }
}